==> apache-artemis-2.33.0-source-release.tar.gz: apache-artemis-2.33.0/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ConnectionFactoryOptions.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.activemq.artemis.jms.client;

/**
 * Common interface to be used to share common parameters between the RA and client JMS.
 * Initially developed to carry on Serialization packages allow list, but it could eventually be expanded.
 */
public interface ConnectionFactoryOptions {

   @Deprecated(forRemoval = true)
   String getDeserializationBlackList();

   @Deprecated(forRemoval = true)
   void setDeserializationBlackList(String denyList);

   @Deprecated(forRemoval = true)
   String getDeserializationWhiteList();

   @Deprecated(forRemoval = true)
   void setDeserializationWhiteList(String allowList);

   String getDeserializationDenyList();

   void setDeserializationDenyList(String denyList);

   String getDeserializationAllowList();

   void setDeserializationAllowList(String allowList);

}

==> apache-artemis-2.42.0-source-release.tar.gz: apache-artemis-2.42.0/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ConnectionFactoryOptions.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.activemq.artemis.jms.client;

/**
 * Common interface to be used to share common parameters between the RA and client JMS. Initially developed to carry on
 * Serialization packages allow list, but it could eventually be expanded.
 */
public interface ConnectionFactoryOptions {

   @Deprecated(forRemoval = true)
   String getDeserializationBlackList();

   @Deprecated(forRemoval = true)
   void setDeserializationBlackList(String denyList);

   @Deprecated(forRemoval = true)
   String getDeserializationWhiteList();

   @Deprecated(forRemoval = true)
   void setDeserializationWhiteList(String allowList);

   String getDeserializationDenyList();

   void setDeserializationDenyList(String denyList);

   String getDeserializationAllowList();

   void setDeserializationAllowList(String allowList);

}
